@@ -6,9 +6,12 @@
 #' @param profile character string with the name of the profile.
 #' @param verbose print some C output (TRUE/FALSE)
 #' @export
-#' @examples  \dontrun{read.table("/etc/passwd");
-#' aa_change_profile("myprofile");
-#' read.table("/etc/passwd");
+#' @references http://manpages.ubuntu.com/manpages/precise/man2/aa_change_profile.2.html
+#' @examples  \dontrun{
+#' test <- read.table("/etc/passwd");
+#' aa_change_profile("testprofile");
+#' aa_getcon();
+#' test <- read.table("/etc/passwd");
 #' }
 aa_change_profile <- function(profile, verbose=TRUE){
 	verbose <- as.integer(verbose)
@@ -17,6 +20,7 @@ aa_change_profile <- function(profile, verbose=TRUE){
 	if(output[[1]] == 0){
 		return(invisible())
 	} else{
+		#special warning when changing from one profile into another
 		if(output[[1]] == 13){
 			out <- try(aa_getcon());	
 			if(class(out) != "try-error" && out$con != "unconfined"){
@@ -24,10 +28,15 @@ aa_change_profile <- function(profile, verbose=TRUE){
 				stop("Failed to change profile from: ", out$con, " to: ", profile, ".\n  Note that this is only allowed if the current profile has a 'change_profile -> ",profile,"' directive.");	
 			}
 		}		
-		switch(as.character(output[[1]]),
-			"2" = stop("Failed to change profile to: ", profile, ": Error 2: profile not found.\n  Make sure the profile is available in /etc/apparmor.d/ and loaded.\n  Try running: sudo aa-status."),
-			"13" = stop("Failed to change profile to: ", profile, ": Error 13: permission denied.\n  Maybe there already is a profile loaded? You cannot switch out of a profile.\n  Try the function: aa_getcon()."),
-			stop("Failed to change profile to: ", profile, "\nError:",output[[1]])
+		ermsg <- errno(output[[1]]);
+		ermsg <- switch(ermsg,
+			"ENOENT" = "Profile not found. Make sure the profile is available in /etc/apparmor.d/ and loaded.\n  Try running: sudo aa-status.",
+			"EINVAL" = "The apparmor kernel module is not loaded or the communication via the /proc/*/attr/current file did not conform to protocol.",
+			"ENOMEM" = "Insufficient kernel memory was available.",
+			"EPERM" = "The calling application is not confined by apparmor.",
+			"EACCES" = "Permission denied.\n  Maybe there already is a profile loaded? You cannot switch out of a profile.\n  Have a look at: aa_getcon().",
+			ermsg
 		);
+		stop("Failed to change profile\n", ermsg);	
 	}
 }
\ No newline at end of file
