@@ -1,3 +1,4 @@
+\dontrun{
 #load lib
 library(RAppArmor)
 
@@ -25,4 +26,5 @@ rlimit_nproc(100);
 rlimit_rttime(1e9);
 rlimit_sigpending(1e4);
 rlimit_stack(1000);
-rlimit_cpu(10);
+rlimit_cpu(60);
+}
